// Copyright (c) Caliper Corporation 2003.  All Rights Reserved
// Written by Phil Villars - Caliper Corporation - 2003

    // This macro demonstrates use of the CreateFigure() Macro Function
    
    // This macro is a demonstration of the use of the CreateFigure() macro function which
    // is used to create charts (line, scatter, bar, pie, etc.).  The function itself
    // takes only three arguments: the desired figure name, the type of figure, and
    // an options array.  The options array is used to specify all the parameters of
    // the desired chart, including the values to be plotted.
    // 
    // The user can experiment with inputting different "labels" and "values" arrays
    // and specifying different chart types to see what kind of behavior they get.
    // Ambitious users can try generating the labels and values arrays from data
    // in a database, such as a map layer or a table.  Users can also experiment with
    // some of the various options, such as "Grouped" vs. "Stacked".
    //
    // Also demonstrated in this demo:
    //
    //    GeneratePalatte()
    //    Options Arrays
    //
    // The macro creates three separate figures to demonstrate the different ways of
    // using the CreateFigure() function.
    
    // To run this macro using the GISDK toolbox:
    // 1. Choose Tools-Add-Ins and open the GIS Developer's Kit toolbox.
    // 2. Compile this macro in test mode using the first button (Compile).
    // 3. Run this macro by clicking the second button (Test), typing the macro 
    //    name "Main", clicking the Macro radio button, and clicking OK.

Macro "Main"

  // ************************************************************
  // Create a simple bar chart based on a simple array of labels and values

  opts = {{"Chart Type", "Bar"}}

  a_labels = {"a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o", "p"}
  a_values = {1, 2 ,3, 5, 8, 13, 18, 20, 22, 21, 19, 14, 7, 4, 2, 1}

  opts = opts + {{"Labels", a_labels}, {"Values", a_values}}
  opts = opts + {{"Label Font", "Arial|Bold|11"}}

  a_colors1 = GeneratePalette(ColorRGB(64000, 0, 0), ColorRGB(0, 64000, 0), 14, {{"Method", "HLS"}, {"Spiral", "FORWARD"}})
  a_colors2 = GeneratePalette(ColorRGB(30000, 20000, 0), ColorRGB(, 30000, 20000), 14, {{"Method", "HLS"}, {"Spiral", "FORWARD"}})

  opts = opts + {{"Colors", a_colors1}}
  
  CreateFigure("Single Series Bar Chart", "Chart", opts)

  // *************************************************************
  // Create another simple bar chart using grouped series of values

  opts = {{"Chart Type", "Bar"}}

  a_labels = {"a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o", "p"}
  a_values = {{1,2}, {1,2}, {3,3}, {5,4}, {8, 7}, {13, 12}, {18, 16}, {20,19}, {22,20}, {21, 20}, {19,17}, {14,12}, {7, 4}, {4, 4}, {2,1}, {1,1}}

  opts = opts + {{"Labels", a_labels}, {"Values", a_values}}
  opts = opts + {{"Label Font", "Arial|Bold|11"}}

  // Specify that you want the series data "grouped", instead of "stacked" -- try switching it to see what it
  // looks like
  opts = opts + {{"Grouped", "True"}}

  // Note that in a grouped bar chart the colors specification is a little different
  a_colors = {ColorRGB(40000, 0, 20000), ColorRGB(12000, 40000, 20000)}

  opts = opts + {{"Colors", a_colors}}
  opts = opts + {{"Position", 10, 10}}

  opts = opts + {{"Legend", {"Series A", "Series B"}}}
  
  CreateFigure("Grouped Series Bar Chart", "Chart", opts)

  // *************************************************************
  // Create a simple pie chart

  opts = {{"Chart Type", "Pie"}}

  a_labels = {"Sales", "Marketing", "R & D", "Accounting", "Operations", "Human Resources"}
  a_values = {120000, 80000, 75000, 10000, 12000,  230000}
  exploded = {"False", "False", "False", "True", "False", "False"}

  opts = opts + {{"Labels", a_labels}, {"Values", a_values}}
  opts = opts + {{"Label Bars", "True"}}
  opts = opts + {{"Label Font", "Arial|Bold|11"}}
  opts = opts + {{"Exploded", exploded}}

  num_colors = ArrayLength(a_labels)

  a_colors1 = GeneratePalette(ColorRGB(64000, 0, 0), ColorRGB(0, 64000, 0), num_colors, {{"Method", "HLS"}, {"Spiral", "FORWARD"}})

  opts = opts + {{"3D", "True"}}
  opts = opts + {{"Colors", a_colors1}}
  opts = opts + {{"Position", 20, 20}}

  CreateFigure("Pie Chart", "Chart", opts)

endMacro